@@ -6,7 +6,7 @@
 
 """
 
-__version__ = "0.9.4"
+__version__ = "0.9.5"
 __license__ = 'MIT'
 __author__ = "@byteface"
 
@@ -17,7 +17,7 @@ import re
 
 import requests
 
-from domonic.components import Input
+# from domonic.components import Input
 from domonic.html import *
 from domonic.html import html_attributes as attributes
 from domonic.javascript import *
@@ -595,7 +595,7 @@ class domonic:
             line = ', '.join(params)
             line = line.replace('" _', '", _')
 
-            if( line[len(line) - 1] in ["'", '"', ")", "$QUOTE$", "}", "e"]):  # TODO 'e' is the last letter of True. crap check
+            if(line[len(line) - 1] in ["'", '"', ")", "$QUOTE$", "}", "e"]):  # TODO 'e' is the last letter of True. crap check
                 line = line + ","
 
             return line
@@ -955,7 +955,6 @@ class domonic:
 
         return page
 
-
     parseString_prev_error = None
     @staticmethod
     def parseString(string):  #, parser=None):
