@@ -5,86 +5,40 @@
     Generate HTML using python.
 
 """
+from domonic.dom import (Comment, Document,  # HTMLOptionsCollection,
+                         DocumentType, Element, HTMLAnchorElement,
+                         HTMLAreaElement, HTMLAudioElement, HTMLBaseElement,
+                         HTMLBaseFontElement, HTMLBodyElement, HTMLBRElement,
+                         HTMLButtonElement, HTMLCanvasElement,
+                         HTMLContentElement, HTMLDataElement,
+                         HTMLDataListElement, HTMLDialogElement,
+                         HTMLDivElement, HTMLDListElement, HTMLDocument,
+                         HTMLElement, HTMLEmbedElement, HTMLFieldSetElement,
+                         HTMLFormControlsCollection, HTMLFormElement,
+                         HTMLFrameSetElement, HTMLHeadElement,
+                         HTMLHeadingElement, HTMLHRElement, HTMLIFrameElement,
+                         HTMLImageElement, HTMLInputElement,
+                         HTMLIsIndexElement, HTMLKeygenElement,
+                         HTMLLabelElement, HTMLLegendElement, HTMLLIElement,
+                         HTMLLinkElement, HTMLMapElement, HTMLMediaElement,
+                         HTMLMetaElement, HTMLMeterElement, HTMLModElement,
+                         HTMLObjectElement, HTMLOListElement,
+                         HTMLOptGroupElement, HTMLOptionElement,
+                         HTMLOutputElement, HTMLParagraphElement,
+                         HTMLParamElement, HTMLPictureElement, HTMLPreElement,
+                         HTMLProgressElement, HTMLQuoteElement,
+                         HTMLScriptElement, HTMLSelectElement,
+                         HTMLShadowElement, HTMLSourceElement, HTMLSpanElement,
+                         HTMLStyleElement, HTMLTableCaptionElement,
+                         HTMLTableCellElement, HTMLTableColElement,
+                         HTMLTableDataCellElement, HTMLTableElement,
+                         HTMLTableHeaderCellElement, HTMLTableRowElement,
+                         HTMLTableSectionElement, HTMLTemplateElement,
+                         HTMLTextAreaElement, HTMLTimeElement,
+                         HTMLTitleElement, HTMLTrackElement, HTMLUListElement,
+                         HTMLUnknownElement, HTMLVideoElement, Node, Text)
 from domonic.webapi.url import URL
 
-from domonic.dom import Node, Element, Document, DocumentType, Comment, Text
-from domonic.dom import (
-    HTMLElement,
-    HTMLAnchorElement,
-    HTMLAreaElement,
-    HTMLAudioElement,
-    HTMLBRElement,
-    HTMLBaseElement,
-    HTMLBaseFontElement,
-    HTMLBodyElement,
-    HTMLButtonElement,
-    HTMLCanvasElement,
-    HTMLContentElement,
-    HTMLDListElement,
-    HTMLDataElement,
-    HTMLDataListElement,
-    HTMLDialogElement,
-    HTMLDivElement,
-    HTMLDocument,
-    HTMLEmbedElement,
-    HTMLFieldSetElement,
-    HTMLFormControlsCollection,
-    HTMLFormElement,
-    HTMLFrameSetElement,
-    HTMLHRElement,
-    HTMLHeadElement,
-    HTMLHeadingElement,
-    HTMLIFrameElement,
-    HTMLImageElement,
-    HTMLInputElement,
-    HTMLIsIndexElement,
-    HTMLKeygenElement,
-    HTMLLIElement,
-    HTMLLabelElement,
-    HTMLLegendElement,
-    HTMLLinkElement,
-    HTMLMapElement,
-    HTMLMediaElement,
-    HTMLMetaElement,
-    HTMLMeterElement,
-    HTMLModElement,
-    HTMLOListElement,
-    HTMLObjectElement,
-    HTMLOptGroupElement,
-    HTMLOptionElement,
-    # HTMLOptionsCollection,
-    HTMLOutputElement,
-    HTMLParagraphElement,
-    HTMLParamElement,
-    HTMLPictureElement,
-    HTMLPreElement,
-    HTMLProgressElement,
-    HTMLQuoteElement,
-    HTMLScriptElement,
-    HTMLSelectElement,
-    HTMLShadowElement,
-    HTMLSourceElement,
-    HTMLSpanElement,
-    HTMLStyleElement,
-    HTMLTableCaptionElement,
-    HTMLTableCellElement,
-    HTMLTableColElement,
-    HTMLTableDataCellElement,
-    HTMLTableElement,
-    HTMLTableHeaderCellElement,
-    HTMLTableRowElement,
-    HTMLTableSectionElement,
-    HTMLTemplateElement,
-    HTMLTextAreaElement,
-    HTMLTimeElement,
-    HTMLTitleElement,
-    HTMLTrackElement,
-    HTMLUListElement,
-    HTMLUnknownElement,
-    HTMLVideoElement,
-)
-
-
 html_tags = [
     "figcaption",
     "blockquote",
